---
home: true
navImage: /assets/img/biome.svg
heroImage: /assets/img/biome-isotype.svg
heroText: biome.
heroSubText: text
tagline: Practical NLP open source library
actionText: Get Started
actionLink: /documentation/
features:
- title: Easy to use
  details: Create natural language processing custom models with powerful building blocks and simple workflows.
- title: Powerful
  details:  Benefit from the latest research and models in NLP powered by PyTorch, AllenNLP and Huggingface.
  img1: /assets/img/pytorch.svg
  img2: /assets/img/allennlp.png
  img3: /assets/img/hugging.png
- title: Industry-ready
  details: Easily package and serve your models in production.
footer: Maintained by
---
